==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorPushTransactionTimeout.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserFactorPushTransaction;
import com.okta.sdk.resource.model.UserFactorPushTransactionRejectedAllOfProfile;
import com.okta.sdk.resource.model.UserFactorPushTransactionTimeoutAllOfLinks;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionTimeout
 */
@JsonPropertyOrder({ UserFactorPushTransactionTimeout.JSON_PROPERTY_PROFILE,
        UserFactorPushTransactionTimeout.JSON_PROPERTY_LINKS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "factorResult", visible = true, defaultImpl = UserFactorPushTransactionTimeout.class)

public class UserFactorPushTransactionTimeout extends UserFactorPushTransaction implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PROFILE = "profile";
    private UserFactorPushTransactionRejectedAllOfProfile profile;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private UserFactorPushTransactionTimeoutAllOfLinks links;

    public UserFactorPushTransactionTimeout() {
    }

    public UserFactorPushTransactionTimeout profile(UserFactorPushTransactionRejectedAllOfProfile profile) {

        this.profile = profile;
        return this;
    }

    /**
     * Get profile
     *
     * @return profile
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactorPushTransactionRejectedAllOfProfile getProfile() {
        return profile;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfile(UserFactorPushTransactionRejectedAllOfProfile profile) {
        this.profile = profile;
    }

    public UserFactorPushTransactionTimeout links(UserFactorPushTransactionTimeoutAllOfLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactorPushTransactionTimeoutAllOfLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(UserFactorPushTransactionTimeoutAllOfLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionTimeout userFactorPushTransactionTimeout = (UserFactorPushTransactionTimeout) o;
        return Objects.equals(this.profile, userFactorPushTransactionTimeout.profile)
                && Objects.equals(this.links, userFactorPushTransactionTimeout.links);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(profile, links, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionTimeout {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    profile: ").append(toIndentedString(profile)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorPushTransactionTimeout.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserFactorPushTransaction;
import com.okta.sdk.resource.model.UserFactorPushTransactionRejectedAllOfProfile;
import com.okta.sdk.resource.model.UserFactorPushTransactionTimeoutAllOfLinks;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionTimeout
 */
@JsonPropertyOrder({ UserFactorPushTransactionTimeout.JSON_PROPERTY_PROFILE,
        UserFactorPushTransactionTimeout.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "factorResult", visible = true, defaultImpl = UserFactorPushTransactionTimeout.class)

public class UserFactorPushTransactionTimeout extends UserFactorPushTransaction implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PROFILE = "profile";
    private UserFactorPushTransactionRejectedAllOfProfile profile;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private UserFactorPushTransactionTimeoutAllOfLinks links;

    public UserFactorPushTransactionTimeout() {
    }

    public UserFactorPushTransactionTimeout profile(UserFactorPushTransactionRejectedAllOfProfile profile) {

        this.profile = profile;
        return this;
    }

    /**
     * Get profile
     *
     * @return profile
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactorPushTransactionRejectedAllOfProfile getProfile() {
        return profile;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfile(UserFactorPushTransactionRejectedAllOfProfile profile) {
        this.profile = profile;
    }

    public UserFactorPushTransactionTimeout links(UserFactorPushTransactionTimeoutAllOfLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactorPushTransactionTimeoutAllOfLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(UserFactorPushTransactionTimeoutAllOfLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionTimeout userFactorPushTransactionTimeout = (UserFactorPushTransactionTimeout) o;
        return Objects.equals(this.profile, userFactorPushTransactionTimeout.profile)
                && Objects.equals(this.links, userFactorPushTransactionTimeout.links);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(profile, links, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionTimeout {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    profile: ").append(toIndentedString(profile)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
